#
# spec file for package inspircd
#

%define with_sqlite3 1
%define with_mysql   1
%define with_pgsql   1
%define with_ldap    1
%define with_geoip   1

Name:           inspircd
Version:        2.0.17
Release:        4%{?dist}
License:        GPL-2.0
Group:          Productivity/Networking/IRC

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc-c++ openssl-devel gnutls-devel pcre-devel pkgconfig zlib-devel

%if 0%{?with_sqlite3}
BuildRequires:  sqlite-devel >= 3.3
%endif
%if 0%{?with_mysql}
BuildRequires:  mysql-devel
%endif
%if 0%{?with_ldap}
BuildRequires:  openldap-devel
%endif
%if 0%{?with_geoip}
BuildRequires:  GeoIP-devel
%endif
%if 0%{?with_pgsql}
BuildRequires: postgresql-devel
%endif
Provides:       %{name} = %{version}-%{release}
Obsoletes:      %{name} < %{version}
Provides:       inspircd12 = %{version}
Obsoletes:      inspircd12 < %{version}
Provides:       inspircd2 = %{version}
Obsoletes:      inspircd2 < %{version}

%define home_dir %{_var}/lib/%{name}
%define pid_dir  %{_var}/run/%{name}
%define log_dir  %{_var}/log/%{name}

Url:            http://www.inspircd.org
Source:         %{name}-%{version}.tar.gz
Source1:        %{name}-extras-master-20130820.tar.gz
Source2:        %{name}.init
Patch1:         sqlauth_with_clientcert.diff
Patch2:         users.cpp_debug.diff
Patch3:         m_sslinfo.cpp_debug.diff

Summary:        A modular C++ IRC Daemon
%description
InspIRCd is a modular C++ IRC Daemon for Linux, BSD and Windows systems created
to provide a stable, modern, lightweight ircd (irc server) from scratch and
provide a vast number of features in a modularised form using an advanced
module API. By keeping the functionality of the main core to a minimum we hope
to increase the stability and speed of our project and make it customisable to
the needs of many users. InspIRCd is designed primarily to be a custom irc
server for the chatspike irc network (irc.chatspike.net) but we are releasing
it into the public domain under GPL so that you may benefit yourself from our
work. The project is written from scratch, avoiding the inherent instability
under large loads which can be seen in many other irc server distributions
which have the same featureset.

%if 0%{?with_sqlite3}
%package modules-sqlite3
Group:          Productivity/Networking/IRC
Summary:        Sqlite3 backend for the inspircd SQL modules
%description modules-sqlite3
InspIRCd is a modular C++ IRC Daemon for Linux, BSD and Windows systems created
to provide a stable, modern, lightweight ircd (irc server) from scratch and
provide a vast number of features in a modularised form using an advanced
module API.

This package holds the sqlite3 backend for the SQL modules.
%endif

%if 0%{?with_mysql}
%package modules-mysql
Group:          Productivity/Networking/IRC
Summary:        Mysql backend for the inspircd SQL modules
%description modules-mysql
InspIRCd is a modular C++ IRC Daemon for Linux, BSD and Windows systems created
to provide a stable, modern, lightweight ircd (irc server) from scratch and
provide a vast number of features in a modularised form using an advanced
module API.

This package holds the Mysql backend for the SQL modules.
%endif

%if 0%{?with_pgsql}
%package modules-pgsql
Group:          Productivity/Networking/IRC
Summary:        Postgresql backend for the inspircd SQL modules
%description modules-pgsql
InspIRCd is a modular C++ IRC Daemon for Linux, BSD and Windows systems created
to provide a stable, modern, lightweight ircd (irc server) from scratch and
provide a vast number of features in a modularised form using an advanced
module API.

This package holds the postgresql backend for the SQL modules.
%endif

%if 0%{?with_geoip}
%package modules-geoip
Group:          Productivity/Networking/IRC
Summary:        GeoIP module for inspircd
%description modules-geoip
InspIRCd is a modular C++ IRC Daemon for Linux, BSD and Windows systems created
to provide a stable, modern, lightweight ircd (irc server) from scratch and
provide a vast number of features in a modularised form using an advanced
module API.

This package holds the GeoIP module.
%endif

%if 0%{?with_ldap}
%package modules-ldap
Group:          Productivity/Networking/IRC
Summary:        LDAP modules for inspircd
%description modules-ldap
InspIRCd is a modular C++ IRC Daemon for Linux, BSD and Windows systems created
to provide a stable, modern, lightweight ircd (irc server) from scratch and
provide a vast number of features in a modularised form using an advanced
module API.

This package holds the LDAP modules.
%endif

%prep
# unpack Source1 (extras) after cd
%setup -n %{name}-%{version} -a 1
%patch1
%patch2
%patch3
pushd src/modules/
    # in order to enable extras, they either
    # - have to be symlinked to src/modules, or
    # - included via ./configure --enable-extras=m_extra.cpp
    #
    # TODO maybe switch to second option later.
    for i in $(ls extra/*sql* extra/*pcre* extra/m_ssl_openssl.cpp/m_ssl_gnutls.cpp | \
            grep -vE '(sqlite3|mysql|mssql|pgsql)'); do
        %{__ln_s} -v $i .
    done
    %if 0%{?with_sqlite3}
        %{__ln_s} -v extra/m_sqlite3.cpp .
    %endif
    %if 0%{?with_mysql}
        %{__ln_s} -v extra/m_mysql.cpp .
    %endif
    %if 0%{?with_pgsql}
        %{__ln_s} -v extra/m_pgsql.cpp .
    %endif
    %if 0%{?with_geoip}
        %{__ln_s} -v extra/m_geoip.cpp .
    %endif
    %if 0%{?with_ldap}
        %{__ln_s} -v extra/m_ldapauth.cpp extra/m_ldapoper.cpp .
    %endif
    # next, symlink the modules from the inspircd-extras project, too.
    for i in m_antibear.cpp m_antibottler.cpp m_antirandom.cpp m_changecap.cpp m_conn_banner.cpp m_custompenalty.cpp m_findxline.cpp m_hideidle.cpp m_invisible.cpp m_invitenotify.cpp m_ircxusernames.cpp m_join0.cpp m_joinpartsno.cpp m_namedstats.cpp m_noctcp_user.cpp m_pretenduser.cpp m_privdeaf.cpp m_quietban.cpp; do
      %{__ln_s} -v ../../%{name}-extras-master/2.0/$i . ; 
    done
popd

%build
export SUSE_ASNEEDED=0
export CXXFLAGS="%{optflags} -fno-strict-aliasing"
# -fno-strict-aliasing" might be needed when compiling with -O2
./configure \
    --disable-interactive \
    --enable-epoll \
    --enable-openssl \
    --enable-gnutls \
    --prefix=%{_prefix}/lib/%{name}/ \
    --config-dir=%{_sysconfdir}/%{name} \
    --module-dir=%{_libdir}/%{name}/modules \
    --binary-dir=%{_sbindir} \
    --disable-debuginfo # get rid of the -g1
perl -p -i -e 's|^(CXXFLAGS = .*)$|$1 %{optflags}|' GNUmakefile
perl -p -i -e 's|^(LDLIBS = .*)$|$1 -Wl,-z,relro,-z,now -pie|' GNUmakefile
perl -p -i -e 's|^(LDFLAGS = .*)$|$1 -Wl,-z,relro,-z,now|' GNUmakefile
%{__make} V=1

%install
# TODO find out if this has any benefit.
make install DESTDIR=%{buildroot} V=1
%{__install} -d %{buildroot}{%{home_dir},%{pid_dir},%{log_dir}}

# move all files out of the examples dir
mv %{buildroot}%{_sysconfdir}/%{name}/examples/* \
    %{buildroot}%{_sysconfdir}/%{name}/
# remove .example suffix
for file in %{buildroot}%{_sysconfdir}/%{name}/*.example; do
    %{__mv} -v ${file} ${file%%.example};
done
for file in %{buildroot}%{_sysconfdir}/%{name}/modules/*.example; do
    %{__mv} -v ${file} ${file%%.example};
done
for file in %{buildroot}%{_sysconfdir}/%{name}/aliases/*.example; do
    %{__mv} -v ${file} ${file%%.example};
done
rmdir %{buildroot}%{_sysconfdir}/%{name}/examples/
chmod -R u=rwX,g=rX,o= %{buildroot}%{_sysconfdir}
%{__install} -D -m 0755 %{S:2}        %{buildroot}%{_sysconfdir}/init.d/%{name}
%{__ln_s} -f %{_sysconfdir}/init.d/%{name}    %{buildroot}%{_sbindir}/rc%{name}

%clean
# TODO iirc this isn't needed on OBS.
#%%{__rm} -rf %%{buildroot}

%pre
/usr/sbin/groupadd -r %{name} &>/dev/null ||:
/usr/sbin/useradd  -r -g %{name} -s /bin/false -c "%{name} irc server" \
    -d %{home_dir} %{name} &>/dev/null ||:

%post
/sbin/chkconfig --add %{name}

%preun
/sbin/service %{name} stop
/sbin/chkconfig --del %{name}

#%postun

%files
%defattr(-,root,root,-)
%{_sbindir}/%{name}
%config(noreplace) %{_sysconfdir}/init.d/%{name}
%{_sbindir}/rc%{name}

%dir %attr(-,root,%{name}) %{_sysconfdir}/%{name}/
%config(noreplace) %attr(-,root,%{name}) %{_sysconfdir}/%{name}/censor.conf
%config(noreplace) %attr(-,root,%{name}) %{_sysconfdir}/%{name}/filter.conf
%config(noreplace) %attr(-,root,%{name}) %{_sysconfdir}/%{name}/helpop-full.conf
%config(noreplace) %attr(-,root,%{name}) %{_sysconfdir}/%{name}/helpop.conf
%config(noreplace) %attr(-,root,%{name}) %{_sysconfdir}/%{name}/inspircd.conf
%config(noreplace) %attr(-,root,%{name}) %{_sysconfdir}/%{name}/links.conf
%config(noreplace) %attr(-,root,%{name}) %{_sysconfdir}/%{name}/modules.conf
%config(noreplace) %attr(-,root,%{name}) %{_sysconfdir}/%{name}/motd.txt
%config(noreplace) %attr(-,root,%{name}) %{_sysconfdir}/%{name}/opermotd.txt
%config(noreplace) %attr(-,root,%{name}) %{_sysconfdir}/%{name}/opers.conf
%config(noreplace) %attr(-,root,%{name}) %{_sysconfdir}/%{name}/quotes.txt
%config(noreplace) %attr(-,root,%{name}) %{_sysconfdir}/%{name}/rules.txt
%dir %attr(-,root,%{name}) %{_sysconfdir}/%{name}/aliases/
%config(noreplace) %attr(-,root,%{name}) %{_sysconfdir}/%{name}/aliases/anope.conf
%config(noreplace) %attr(-,root,%{name}) %{_sysconfdir}/%{name}/aliases/atheme.conf
%config(noreplace) %attr(-,root,%{name}) %{_sysconfdir}/%{name}/aliases/ircservices.conf
%config(noreplace) %attr(-,root,%{name}) %{_sysconfdir}/%{name}/aliases/neostats.conf
%dir %attr(-,root,%{name}) %{_sysconfdir}/%{name}/modules/
%config(noreplace) %attr(-,root,%{name}) %{_sysconfdir}/%{name}/modules/charybdis.conf
%config(noreplace) %attr(-,root,%{name}) %{_sysconfdir}/%{name}/modules/unrealircd.conf

%doc docs/*

%attr(0750,%{name},%{name})        %{log_dir}
%attr(0750,%{name},%{name})        %{home_dir}

%dir %{_prefix}/lib/%{name}
%{_prefix}/lib/%{name}/%{name}
# TODO what does this do?
# W: hidden-file-or-dir /usr/lib/inspircd/.gdbargs
# The file or directory is hidden. You should see if this is normal, and delete
# it from the package if not.
%{_prefix}/lib/%{name}/.gdbargs

%dir %{_libdir}/%{name}/
%dir %{_libdir}/%{name}/modules/
%{_libdir}/%{name}/modules/cmd_admin.so
%{_libdir}/%{name}/modules/cmd_away.so
%{_libdir}/%{name}/modules/cmd_clearcache.so
%{_libdir}/%{name}/modules/cmd_commands.so
%{_libdir}/%{name}/modules/cmd_connect.so
%{_libdir}/%{name}/modules/cmd_die.so
%{_libdir}/%{name}/modules/cmd_eline.so
%{_libdir}/%{name}/modules/cmd_gline.so
%{_libdir}/%{name}/modules/cmd_info.so
%{_libdir}/%{name}/modules/cmd_invite.so
%{_libdir}/%{name}/modules/cmd_ison.so
%{_libdir}/%{name}/modules/cmd_join.so
%{_libdir}/%{name}/modules/cmd_kick.so
%{_libdir}/%{name}/modules/cmd_kill.so
%{_libdir}/%{name}/modules/cmd_kline.so
%{_libdir}/%{name}/modules/cmd_links.so
%{_libdir}/%{name}/modules/cmd_list.so
%{_libdir}/%{name}/modules/cmd_loadmodule.so
%{_libdir}/%{name}/modules/cmd_lusers.so
%{_libdir}/%{name}/modules/cmd_map.so
%{_libdir}/%{name}/modules/cmd_modenotice.so
%{_libdir}/%{name}/modules/cmd_mode.so
%{_libdir}/%{name}/modules/cmd_modules.so
%{_libdir}/%{name}/modules/cmd_motd.so
%{_libdir}/%{name}/modules/cmd_names.so
%{_libdir}/%{name}/modules/cmd_nick.so
%{_libdir}/%{name}/modules/cmd_notice.so
%{_libdir}/%{name}/modules/cmd_oper.so
%{_libdir}/%{name}/modules/cmd_part.so
%{_libdir}/%{name}/modules/cmd_pass.so
%{_libdir}/%{name}/modules/cmd_ping.so
%{_libdir}/%{name}/modules/cmd_pong.so
%{_libdir}/%{name}/modules/cmd_privmsg.so
%{_libdir}/%{name}/modules/cmd_qline.so
%{_libdir}/%{name}/modules/cmd_quit.so
%{_libdir}/%{name}/modules/cmd_rehash.so
%{_libdir}/%{name}/modules/cmd_reloadmodule.so
%{_libdir}/%{name}/modules/cmd_restart.so
%{_libdir}/%{name}/modules/cmd_rules.so
%{_libdir}/%{name}/modules/cmd_server.so
%{_libdir}/%{name}/modules/cmd_squit.so
%{_libdir}/%{name}/modules/cmd_stats.so
%{_libdir}/%{name}/modules/cmd_time.so
%{_libdir}/%{name}/modules/cmd_topic.so
%{_libdir}/%{name}/modules/cmd_unloadmodule.so
%{_libdir}/%{name}/modules/cmd_userhost.so
%{_libdir}/%{name}/modules/cmd_user.so
%{_libdir}/%{name}/modules/cmd_version.so
%{_libdir}/%{name}/modules/cmd_wallops.so
%{_libdir}/%{name}/modules/cmd_whois.so
%{_libdir}/%{name}/modules/cmd_who.so
%{_libdir}/%{name}/modules/cmd_whowas.so
%{_libdir}/%{name}/modules/cmd_zline.so
%{_libdir}/%{name}/modules/m_abbreviation.so
%{_libdir}/%{name}/modules/m_alias.so
%{_libdir}/%{name}/modules/m_allowinvite.so
%{_libdir}/%{name}/modules/m_alltime.so
%{_libdir}/%{name}/modules/m_auditorium.so
%{_libdir}/%{name}/modules/m_autoop.so
%{_libdir}/%{name}/modules/m_banexception.so
%{_libdir}/%{name}/modules/m_banredirect.so
%{_libdir}/%{name}/modules/m_blockamsg.so
%{_libdir}/%{name}/modules/m_blockcaps.so
%{_libdir}/%{name}/modules/m_blockcolor.so
%{_libdir}/%{name}/modules/m_botmode.so
%{_libdir}/%{name}/modules/m_callerid.so
%{_libdir}/%{name}/modules/m_cap.so
%{_libdir}/%{name}/modules/m_cban.so
%{_libdir}/%{name}/modules/m_censor.so
%{_libdir}/%{name}/modules/m_cgiirc.so
%{_libdir}/%{name}/modules/m_chancreate.so
%{_libdir}/%{name}/modules/m_chanfilter.so
%{_libdir}/%{name}/modules/m_chanhistory.so
%{_libdir}/%{name}/modules/m_chanlog.so
%{_libdir}/%{name}/modules/m_channames.so
%{_libdir}/%{name}/modules/m_channelban.so
%{_libdir}/%{name}/modules/m_chanprotect.so
%{_libdir}/%{name}/modules/m_check.so
%{_libdir}/%{name}/modules/m_chghost.so
%{_libdir}/%{name}/modules/m_chgident.so
%{_libdir}/%{name}/modules/m_chgname.so
%{_libdir}/%{name}/modules/m_cloaking.so
%{_libdir}/%{name}/modules/m_clones.so
%{_libdir}/%{name}/modules/m_close.so
%{_libdir}/%{name}/modules/m_commonchans.so
%{_libdir}/%{name}/modules/m_connectban.so
%{_libdir}/%{name}/modules/m_connflood.so
%{_libdir}/%{name}/modules/m_conn_join.so
%{_libdir}/%{name}/modules/m_conn_umodes.so
%{_libdir}/%{name}/modules/m_conn_waitpong.so
%{_libdir}/%{name}/modules/m_customprefix.so
%{_libdir}/%{name}/modules/m_customtitle.so
%{_libdir}/%{name}/modules/m_cycle.so
%{_libdir}/%{name}/modules/m_dccallow.so
%{_libdir}/%{name}/modules/m_deaf.so
%{_libdir}/%{name}/modules/m_delayjoin.so
%{_libdir}/%{name}/modules/m_delaymsg.so
%{_libdir}/%{name}/modules/m_denychans.so
%{_libdir}/%{name}/modules/m_devoice.so
%{_libdir}/%{name}/modules/m_dnsbl.so
%{_libdir}/%{name}/modules/m_exemptchanops.so
%{_libdir}/%{name}/modules/m_filter.so
%{_libdir}/%{name}/modules/m_gecosban.so
%{_libdir}/%{name}/modules/m_globalload.so
%{_libdir}/%{name}/modules/m_globops.so
%{_libdir}/%{name}/modules/m_halfop.so
%{_libdir}/%{name}/modules/m_helpop.so
%{_libdir}/%{name}/modules/m_hidechans.so
%{_libdir}/%{name}/modules/m_hideoper.so
%{_libdir}/%{name}/modules/m_hostchange.so
%{_libdir}/%{name}/modules/m_httpd_acl.so
%{_libdir}/%{name}/modules/m_httpd_config.so
%{_libdir}/%{name}/modules/m_httpd.so
%{_libdir}/%{name}/modules/m_httpd_stats.so
%{_libdir}/%{name}/modules/m_ident.so
%{_libdir}/%{name}/modules/m_inviteexception.so
%{_libdir}/%{name}/modules/m_ircv3.so
%{_libdir}/%{name}/modules/m_joinflood.so
%{_libdir}/%{name}/modules/m_jumpserver.so
%{_libdir}/%{name}/modules/m_kicknorejoin.so
%{_libdir}/%{name}/modules/m_knock.so
%{_libdir}/%{name}/modules/m_lockserv.so
%{_libdir}/%{name}/modules/m_maphide.so
%{_libdir}/%{name}/modules/m_md5.so
%{_libdir}/%{name}/modules/m_messageflood.so
%{_libdir}/%{name}/modules/m_mlock.so
%{_libdir}/%{name}/modules/m_muteban.so
%{_libdir}/%{name}/modules/m_namedmodes.so
%{_libdir}/%{name}/modules/m_namesx.so
%{_libdir}/%{name}/modules/m_nationalchars.so
%{_libdir}/%{name}/modules/m_nickflood.so
%{_libdir}/%{name}/modules/m_nicklock.so
%{_libdir}/%{name}/modules/m_noctcp.so
%{_libdir}/%{name}/modules/m_nokicks.so
%{_libdir}/%{name}/modules/m_nonicks.so
%{_libdir}/%{name}/modules/m_nonotice.so
%{_libdir}/%{name}/modules/m_nopartmsg.so
%{_libdir}/%{name}/modules/m_ojoin.so
%{_libdir}/%{name}/modules/m_operchans.so
%{_libdir}/%{name}/modules/m_operjoin.so
%{_libdir}/%{name}/modules/m_operlevels.so
%{_libdir}/%{name}/modules/m_operlog.so
%{_libdir}/%{name}/modules/m_opermodes.so
%{_libdir}/%{name}/modules/m_opermotd.so
%{_libdir}/%{name}/modules/m_operprefix.so
%{_libdir}/%{name}/modules/m_override.so
%{_libdir}/%{name}/modules/m_passforward.so
%{_libdir}/%{name}/modules/m_password_hash.so
%{_libdir}/%{name}/modules/m_permchannels.so
%{_libdir}/%{name}/modules/m_randquote.so
%{_libdir}/%{name}/modules/m_redirect.so
%{_libdir}/%{name}/modules/m_regex_glob.so
%{_libdir}/%{name}/modules/m_regex_pcre.so
%{_libdir}/%{name}/modules/m_regex_posix.so
%{_libdir}/%{name}/modules/m_regonlycreate.so
%{_libdir}/%{name}/modules/m_remove.so
%{_libdir}/%{name}/modules/m_restrictchans.so
%{_libdir}/%{name}/modules/m_restrictmsg.so
%{_libdir}/%{name}/modules/m_ripemd160.so
%{_libdir}/%{name}/modules/m_rline.so
%{_libdir}/%{name}/modules/m_sajoin.so
%{_libdir}/%{name}/modules/m_sakick.so
%{_libdir}/%{name}/modules/m_samode.so
%{_libdir}/%{name}/modules/m_sanick.so
%{_libdir}/%{name}/modules/m_sapart.so
%{_libdir}/%{name}/modules/m_saquit.so
%{_libdir}/%{name}/modules/m_sasl.so
%{_libdir}/%{name}/modules/m_satopic.so
%{_libdir}/%{name}/modules/m_securelist.so
%{_libdir}/%{name}/modules/m_seenicks.so
%{_libdir}/%{name}/modules/m_serverban.so
%{_libdir}/%{name}/modules/m_services_account.so
%{_libdir}/%{name}/modules/m_servprotect.so
%{_libdir}/%{name}/modules/m_sethost.so
%{_libdir}/%{name}/modules/m_setident.so
%{_libdir}/%{name}/modules/m_setidle.so
%{_libdir}/%{name}/modules/m_setname.so
%{_libdir}/%{name}/modules/m_sha256.so
%{_libdir}/%{name}/modules/m_showwhois.so
%{_libdir}/%{name}/modules/m_shun.so
%{_libdir}/%{name}/modules/m_silence.so
%{_libdir}/%{name}/modules/m_spanningtree.so
%{_libdir}/%{name}/modules/m_sqlauth.so
%{_libdir}/%{name}/modules/m_sqloper.so
%{_libdir}/%{name}/modules/m_sslinfo.so
%{_libdir}/%{name}/modules/m_sslmodes.so
%{_libdir}/%{name}/modules/m_ssl_gnutls.so
%{_libdir}/%{name}/modules/m_ssl_openssl.so
%{_libdir}/%{name}/modules/m_stripcolor.so
%{_libdir}/%{name}/modules/m_svshold.so
%{_libdir}/%{name}/modules/m_swhois.so
%{_libdir}/%{name}/modules/m_testnet.so
%{_libdir}/%{name}/modules/m_timedbans.so
%{_libdir}/%{name}/modules/m_tline.so
%{_libdir}/%{name}/modules/m_topiclock.so
%{_libdir}/%{name}/modules/m_uhnames.so
%{_libdir}/%{name}/modules/m_uninvite.so
%{_libdir}/%{name}/modules/m_userip.so
%{_libdir}/%{name}/modules/m_vhost.so
%{_libdir}/%{name}/modules/m_watch.so
%{_libdir}/%{name}/modules/m_xline_db.so
# extras
%{_libdir}/%{name}/modules/m_antibear.so
%{_libdir}/%{name}/modules/m_antibottler.so
%{_libdir}/%{name}/modules/m_antirandom.so
%{_libdir}/%{name}/modules/m_changecap.so
%{_libdir}/%{name}/modules/m_conn_banner.so
%{_libdir}/%{name}/modules/m_custompenalty.so
%{_libdir}/%{name}/modules/m_findxline.so
%{_libdir}/%{name}/modules/m_hideidle.so
%{_libdir}/%{name}/modules/m_invisible.so
%{_libdir}/%{name}/modules/m_invitenotify.so
%{_libdir}/%{name}/modules/m_ircxusernames.so
%{_libdir}/%{name}/modules/m_join0.so
%{_libdir}/%{name}/modules/m_joinpartsno.so
%{_libdir}/%{name}/modules/m_namedstats.so
%{_libdir}/%{name}/modules/m_noctcp_user.so
%{_libdir}/%{name}/modules/m_pretenduser.so
%{_libdir}/%{name}/modules/m_privdeaf.so
%{_libdir}/%{name}/modules/m_quietban.so

%if 0%{?with_sqlite3}
%files modules-sqlite3
%defattr(-,root,root,-)
%{_libdir}/%{name}/modules/m_sqlite3.so
%endif

%if 0%{?with_mysql}
%files modules-mysql
%defattr(-,root,root,-)
%{_libdir}/%{name}/modules/m_mysql.so
%endif

%if 0%{?with_pgsql}
%files modules-pgsql
%defattr(-,root,root,-)
%{_libdir}/%{name}/modules/m_pgsql.so
%endif

%if 0%{?with_geoip}
%files modules-geoip
%defattr(-,root,root,-)
%{_libdir}/%{name}/modules/m_geoip.so
%endif

%if 0%{?with_ldap}
%files modules-ldap
%defattr(-,root,root,-)
%{_libdir}/%{name}/modules/m_ldapauth.so
%{_libdir}/%{name}/modules/m_ldapoper.so
%endif

%changelog
* Fri Sep 05 2014 Bryan Seitz <seitz@ghettoforge.org> - 2.0.17-4
- Added m_ssl_gnutls.so
* Fri Sep 05 2014 Bryan Seitz <seitz@ghettoforge.org> - 2.0.17-3
- Added m_ssl_gnutls.so
* Thu Sep 04 2014 Bryan Seitz <seitz@ghettoforge.org> - 2.0.17-1
- New upsstream release
* Wed Oct 16 2013 Bryan Seitz <seitz@ghettoforge.org> - 2.0.14-1
- Initial build for GhettoForge
